@@ -1,7 +1,7 @@
 #' @import stats
 NULL
 ###################################################################################
-#  Locally Efficient Doubly Robust DID estimator with Repeated Cross Section Data
+#  Locally Efficient Doubly Robust DiD estimator with Repeated Cross Section Data
 #' Locally efficient doubly robust DiD estimator for the ATT, with repeated cross-section data
 #' @description \code{drdid_rc} is used to compute the locally efficient doubly robust estimators for the ATT
 #'  in difference-in-differences (DiD) setups with stationary repeated cross-sectional data.
@@ -11,7 +11,7 @@ NULL
 #'             and post = 0 if observation belongs to pre-treatment period.)
 #' @param D An \eqn{n} x \eqn{1} vector of Group indicators (=1 if observation is treated in the post-treatment, =0 otherwise).
 #' @param covariates An \eqn{n} x \eqn{k} matrix of covariates to be used in the propensity score and regression estimation.
-#' If covariates = NULL, this leads to an unconditional DID estimator.
+#' If covariates = NULL, this leads to an unconditional DiD estimator.
 #' @param i.weights An \eqn{n} x \eqn{1} vector of weights to be used. If NULL, then every observation has the same weights.
 #' @param boot Logical argument to whether bootstrap should be used for inference. Default is FALSE.
 #' @param boot.type Type of bootstrap to be performed (not relevant if \code{boot = FALSE}). Options are "weighted" and "multiplier".
@@ -20,8 +20,8 @@ NULL
 #' @param inffunc Logical argument to whether influence function should be returned. Default is FALSE.
 #'
 #' @return A list containing the following components:
-#' \item{ATT}{The TR-DR DID point estimate}
-#' \item{se}{ The TR-DR DID standard error}
+#' \item{ATT}{The DR DiD point estimate}
+#' \item{se}{ The DR DiD standard error}
 #' \item{uci}{Estimate of the upper bound of a 95\% CI for the ATT}
 #' \item{lci}{Estimate of the lower bound of a 95\% CI for the ATT}
 #' \item{boots}{All Bootstrap draws of the ATT, in case bootstrap was used to conduct inference. Default is NULL}
@@ -39,7 +39,7 @@ NULL
 #'
 #' @details
 #'
-#' The \code{drdid_rc} function implements the locally efficient doubly robust difference-in-differences (DID)
+#' The \code{drdid_rc} function implements the locally efficient doubly robust difference-in-differences (DiD)
 #' estimator for the average treatment effect on the treated (ATT) defined in equation (3.4)
 #' in Sant'Anna and Zhao (2020). This estimator makes use of a logistic propensity score model for the probability
 #' of being in the treated group, and of (separate) linear regression models for the outcome of both treated and comparison units,
@@ -53,7 +53,7 @@ NULL
 #' @examples
 #' # use the simulated data provided in the package
 #' covX = as.matrix(sim_rc[,5:8])
-#' # Implement the 'traditional' locally efficient DR DID estimator
+#' # Implement the 'traditional' locally efficient DR DiD estimator
 #' drdid_rc(y = sim_rc$y, post = sim_rc$post, D = sim_rc$d,
 #'          covariates= covX)
 #'
@@ -178,21 +178,21 @@ drdid_rc <-function(y, post, D, covariates, i.weights = NULL,
   weights.ols.pre <- i.weights * (1 - D) * (1 - post)
   wols.x.pre <- weights.ols.pre * int.cov
   wols.eX.pre <- weights.ols.pre * (y - out.y.cont.pre) * int.cov
-  XpX.inv.pre <- solve(crossprod(wols.x.pre, int.cov)/n)
+  XpX.inv.pre <- qr.solve(crossprod(wols.x.pre, int.cov)/n)
   asy.lin.rep.ols.pre <-  wols.eX.pre %*% XpX.inv.pre
 
   # Asymptotic linear representation of OLS parameters in post-period, control group
   weights.ols.post <- i.weights * (1 - D) * post
   wols.x.post <- weights.ols.post * int.cov
   wols.eX.post <- weights.ols.post * (y - out.y.cont.post) * int.cov
-  XpX.inv.post <- solve(crossprod(wols.x.post, int.cov)/n)
+  XpX.inv.post <- qr.solve(crossprod(wols.x.post, int.cov)/n)
   asy.lin.rep.ols.post <-  wols.eX.post %*% XpX.inv.post
 
   # Asymptotic linear representation of OLS parameters in pre-period, treated
   weights.ols.pre.treat <- i.weights * D * (1 - post)
   wols.x.pre.treat <- weights.ols.pre.treat * int.cov
   wols.eX.pre.treat <- weights.ols.pre.treat * (y - out.y.treat.pre) * int.cov
-  XpX.inv.pre.treat <- solve(crossprod(wols.x.pre.treat, int.cov)/n)
+  XpX.inv.pre.treat <- qr.solve(crossprod(wols.x.pre.treat, int.cov)/n)
   asy.lin.rep.ols.pre.treat <-  wols.eX.pre.treat %*% XpX.inv.pre.treat
 
 
@@ -200,7 +200,7 @@ drdid_rc <-function(y, post, D, covariates, i.weights = NULL,
   weights.ols.post.treat <- i.weights * D *  post
   wols.x.post.treat <- weights.ols.post.treat * int.cov
   wols.eX.post.treat <- weights.ols.post.treat * (y - out.y.treat.post) * int.cov
-  XpX.inv.post.treat <- solve(crossprod(wols.x.post.treat, int.cov)/n)
+  XpX.inv.post.treat <- qr.solve(crossprod(wols.x.post.treat, int.cov)/n)
   asy.lin.rep.ols.post.treat <-  wols.eX.post.treat %*% XpX.inv.post.treat
 
   # Asymptotic linear representation of logit's beta's
