@@ -10,7 +10,7 @@ NULL
 #' @param y0 An \eqn{n} x \eqn{1} vector of outcomes from the pre-treatment period.
 #' @param D An \eqn{n} x \eqn{1} vector of Group indicators (=1 if observation is treated in the post-treatment, =0 otherwise).
 #' @param covariates An \eqn{n} x \eqn{k} matrix of covariates to be used in the regression estimation.
-#' If covariates = NULL, this leads to an unconditional DID estimator.
+#' If covariates = NULL, this leads to an unconditional DiD estimator.
 #' @param i.weights An \eqn{n} x \eqn{1} vector of weights to be used. If NULL, then every observation has the same weights.
 #' @param boot Logical argument to whether bootstrap should be used for inference. Default is FALSE.
 #' @param boot.type Type of bootstrap to be performed (not relevant if \code{boot = FALSE}). Options are "weighted" and "multiplier".
@@ -19,8 +19,8 @@ NULL
 #' @param inffunc Logical argument to whether influence function should be returned. Default is FALSE.
 #'
 #' @return A list containing the following components:
-#'  \item{ATT}{The Reg DID point estimate}
-#'  \item{se}{The Reg DID standard error}
+#'  \item{ATT}{The OR DiD point estimate}
+#'  \item{se}{The OR DiD standard error}
 #'  \item{uci}{Estimate of the upper bound of a 95\% CI for the ATT}
 #'  \item{lci}{Estimate of the lower bound of a 95\% CI for the ATT}
 #'  \item{boots}{All Bootstrap draws of the ATT, in case bootstrap was used to conduct inference. Default is NULL}
@@ -31,7 +31,7 @@ NULL
 #' @details
 #'
 #' The \code{reg_did_panel} function implements
-#' outcome regression difference-in-differences (DID) estimator for the average treatment effect
+#' outcome regression difference-in-differences (DiD) estimator for the average treatment effect
 #' on the treated (ATT) defined in equation (2.2) of Sant'Anna and Zhao (2020) when panel data are available.
 #' The estimator follows the same spirit of the nonparametric estimators proposed by Heckman, Ichimura and Todd (1997),
 #' though here the the outcome regression models are assumed to be linear in covariates (parametric),
@@ -62,7 +62,7 @@ NULL
 #'                        eval_lalonde_cps$black, eval_lalonde_cps$married,
 #'                        eval_lalonde_cps$nodegree, eval_lalonde_cps$hisp,
 #'                        eval_lalonde_cps$re74))
-#' # Implement OR DID with panel data
+#' # Implement OR DiD with panel data
 #' reg_did_panel(y1 = eval_lalonde_cps$re78, y0 = eval_lalonde_cps$re75,
 #'                D = eval_lalonde_cps$experimental,
 #'                covariates = covX)
@@ -105,7 +105,7 @@ reg_did_panel <-function(y1, y0, D, covariates, i.weights = NULL,
   }
   out.delta <-   as.vector(tcrossprod(reg.coeff, int.cov))
   #-----------------------------------------------------------------------------
-  #Compute the OR-DID estimator
+  #Compute the OR-DiD estimator
   # First, the weights
   w.treat <- i.weights * D
   w.cont <- i.weights * D
@@ -125,7 +125,7 @@ reg_did_panel <-function(y1, y0, D, covariates, i.weights = NULL,
   weights.ols <- i.weights * (1 - D)
   wols.x <- weights.ols * int.cov
   wols.eX <- weights.ols * (deltaY - out.delta) * int.cov
-  XpX.inv <- solve(crossprod(wols.x, int.cov)/n)
+  XpX.inv <- base::qr.solve(crossprod(wols.x, int.cov)/n)
   asy.lin.rep.ols <-  wols.eX %*% XpX.inv
   #-----------------------------------------------------------------------------
   # Now, the influence function of the "treat" component
